#version 330 core

in vec3 Normal;
in vec3 FragPos;
in vec2 v_tex_coords;

out vec4 color;

uniform vec3 object_color;
uniform vec3 light_color;
uniform vec3 light_pos;
uniform vec3 view_pos;

uniform sampler2D tex;

void main()
{
  float ambient_strength = 0.1f;
  vec3 ambient = ambient_strength * light_color;

  vec3 norm = normalize(Normal);
  vec3 lightDir = normalize(light_pos - FragPos);

  float specularStrength = 0.5f;
  vec3 viewDir = normalize(view_pos - FragPos);
  vec3 reflectDir = reflect(-lightDir, norm);
  float spec = pow(max(dot(viewDir, reflectDir), 0.0), 32);
  vec3 specular = specularStrength * spec * light_color;

  float diff = max(dot(norm, lightDir), 0.0);
  vec3  diffuse = diff * light_color;

  vec3 light = (ambient + diffuse + specular) * object_color;

  vec4 texel = texture(tex, v_tex_coords);
  if(texel.a < 0.9)
    color = vec4(light, 1.0);
  else
    color = vec4(light, 1.0) * texel;
}